/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the elasticmapreduce-2009-03-31.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.ElasticMapReduce.Model
{
    /// <summary>
    /// Container for the parameters to the AddInstanceGroups operation.
    /// AddInstanceGroups adds an instance group to a running cluster.
    /// </summary>
    public partial class AddInstanceGroupsRequest : AmazonElasticMapReduceRequest
    {
        private List<InstanceGroupConfig> _instanceGroups = new List<InstanceGroupConfig>();
        private string _jobFlowId;

        /// <summary>
        /// Empty constructor used to set  properties independently even when a simple constructor is available
        /// </summary>
        public AddInstanceGroupsRequest() { }

        /// <summary>
        /// Instantiates AddInstanceGroupsRequest with the parameterized properties
        /// </summary>
        /// <param name="jobFlowId">Job flow in which to add the instance groups.</param>
        /// <param name="instanceGroups">Instance Groups to add.</param>
        public AddInstanceGroupsRequest(string jobFlowId, List<InstanceGroupConfig> instanceGroups)
        {
            _jobFlowId = jobFlowId;
            _instanceGroups = instanceGroups;
        }

        /// <summary>
        /// Gets and sets the property InstanceGroups. 
        /// <para>
        /// Instance Groups to add.
        /// </para>
        /// </summary>
        public List<InstanceGroupConfig> InstanceGroups
        {
            get { return this._instanceGroups; }
            set { this._instanceGroups = value; }
        }

        // Check to see if InstanceGroups property is set
        internal bool IsSetInstanceGroups()
        {
            return this._instanceGroups != null && this._instanceGroups.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property JobFlowId. 
        /// <para>
        /// Job flow in which to add the instance groups.
        /// </para>
        /// </summary>
        public string JobFlowId
        {
            get { return this._jobFlowId; }
            set { this._jobFlowId = value; }
        }

        // Check to see if JobFlowId property is set
        internal bool IsSetJobFlowId()
        {
            return this._jobFlowId != null;
        }

    }
}