/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the email-2010-12-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.SimpleEmail.Model
{
    /// <summary>
    /// Container for the parameters to the VerifyDomainDkim operation.
    /// Returns a set of DKIM tokens for a domain. DKIM <i>tokens</i> are character strings
    /// that represent your domain's identity. Using these tokens, you will need to create
    /// DNS CNAME records that point to DKIM public keys hosted by Amazon SES. Amazon Web
    /// Services will eventually detect that you have updated your DNS records; this detection
    /// process may take up to 72 hours. Upon successful detection, Amazon SES will be able
    /// to DKIM-sign email originating from that domain.
    /// 
    ///  
    /// <para>
    /// This action is throttled at one request per second.
    /// </para>
    ///  
    /// <para>
    /// To enable or disable Easy DKIM signing for a domain, use the <code>SetIdentityDkimEnabled</code>
    /// action.
    /// </para>
    ///  
    /// <para>
    /// For more information about creating DNS records using DKIM tokens, go to the <a href="http://docs.aws.amazon.com/ses/latest/DeveloperGuide/easy-dkim-dns-records.html">Amazon
    /// SES Developer Guide</a>.
    /// </para>
    /// </summary>
    public partial class VerifyDomainDkimRequest : AmazonSimpleEmailServiceRequest
    {
        private string _domain;

        /// <summary>
        /// Gets and sets the property Domain. 
        /// <para>
        /// The name of the domain to be verified for Easy DKIM signing.
        /// </para>
        /// </summary>
        public string Domain
        {
            get { return this._domain; }
            set { this._domain = value; }
        }

        // Check to see if Domain property is set
        internal bool IsSetDomain()
        {
            return this._domain != null;
        }

    }
}